import { Emitter } from 'smart-table-events';
import { SortConfiguration } from './sort';
import { SearchConfiguration } from 'smart-table-search';
import { FilterConfiguration } from 'smart-table-filter';
import { SliceConfiguration } from '../slice';
export declare const enum SmartTableEvents {
    TOGGLE_SORT = "TOGGLE_SORT",
    DISPLAY_CHANGED = "DISPLAY_CHANGED",
    PAGE_CHANGED = "CHANGE_PAGE",
    EXEC_CHANGED = "EXEC_CHANGED",
    FILTER_CHANGED = "FILTER_CHANGED",
    SUMMARY_CHANGED = "SUMMARY_CHANGED",
    SEARCH_CHANGED = "SEARCH_CHANGED",
    EXEC_ERROR = "EXEC_ERROR"
}
export interface TableState {
    search: SearchConfiguration;
    filter: FilterConfiguration;
    sort: SortConfiguration;
    slice: SliceConfiguration;
}
export interface DisplayedItem<T> {
    index: number;
    value: T;
}
export interface DisplayChangeCallback<T> {
    (items: DisplayedItem<T>[]): void;
}
export interface ProcessingOptions {
    processingDelay: number;
}
export interface SmartTable<T> extends Emitter {
    readonly filteredCount: number;
    readonly length: number;
    sort(input?: SortConfiguration): void;
    filter(input?: FilterConfiguration): void;
    slice(input: SliceConfiguration): void;
    search(input?: SearchConfiguration): void;
    eval(tableState?: TableState): Promise<DisplayedItem<T>[]>;
    exec(opts?: ProcessingOptions): void;
    onDisplayChange(callback: DisplayChangeCallback<T>): void;
    getTableState(): TableState;
    getMatchingItems(): T[];
}
export interface TableConfiguration<T> {
    data: T[];
    tableState: TableState;
    sortFactory: (conf: SortConfiguration) => (array: T[]) => T[];
    filterFactory: (conf: FilterConfiguration) => (array: T[]) => T[];
    searchFactory: (conf: SearchConfiguration) => (array: T[]) => T[];
}
export declare const tableDirective: <T>({ sortFactory, tableState, data, filterFactory, searchFactory }: TableConfiguration<T>) => SmartTable<T>;
